@@ -55,12 +55,13 @@ class IntelFFTW(Fftw):
         fftw_libs = ["fftw3xc_intel%s" % fftwsuff]
         if self.options['usempi']:
             # add cluster interface
-            if LooseVersion(imklver) >= LooseVersion("11.0"):
-                fftw_libs.append("fftw3x_cdft_lp64%s" % fftwsuff)
-            elif LooseVersion(imklver) >= LooseVersion("10.3"):
-                fftw_libs.append("fftw3x_cdft%s" % fftwsuff)
-            fftw_libs.append("mkl_cdft_core") ## add cluster dft
-            fftw_libs.extend(self.variables['LIBBLACS'].flatten()) ## add BLACS; use flatten because ListOfList
+            if LooseVersion(imklver) < LooseVersion("11.1"):
+                if LooseVersion(imklver) >= LooseVersion("11.0"):
+                    fftw_libs.append("fftw3x_cdft_lp64%s" % fftwsuff)
+                elif LooseVersion(imklver) >= LooseVersion("10.3"):
+                    fftw_libs.append("fftw3x_cdft%s" % fftwsuff)
+                fftw_libs.append("mkl_cdft_core")  # add cluster dft
+                fftw_libs.extend(self.variables['LIBBLACS'].flatten()) ## add BLACS; use flatten because ListOfList
 
         self.log.debug('fftw_libs %s' % fftw_libs.__repr__())
         fftw_libs.extend(self.variables['LIBBLAS'].flatten()) ## add core (contains dft) ; use flatten because ListOfList
@@ -72,10 +73,9 @@ class IntelFFTW(Fftw):
         # building the FFTW interfaces is optional,
         # so make sure libraries are there before FFT_LIB is set
         imklroot = get_software_root(self.FFT_MODULE_NAME[0])
-        if all([any([os.path.exists(os.path.join(imklroot, libdir, "lib%s.a" % lib)) for libdir in self.FFT_LIB_DIR])
-                for lib in fftw_libs]):
+        fft_lib_dirs = [os.path.join(imklroot, d) for d in self.FFT_LIB_DIR]
+        if all([any([os.path.exists(os.path.join(d, "lib%s.a" % lib)) for d in fft_lib_dirs]) for lib in fftw_libs]):
             self.FFT_LIB = fftw_libs
         else:
-            self.log.error("Not all FFTW interface libraries (%s) are found in %s, can't set FFT_LIB." % \
-                           (fftw_libs, self.FFT_LIB_DIR))
-            self.FFT_LIB = []
+            msg = "Not all FFTW interface libraries %s are found in %s, can't set FFT_LIB." % (fftw_libs, fft_lib_dirs)
+            self.log.error(msg)
