@@ -39,11 +39,13 @@ from easybuild.tools.toolchain.linalg import LinAlg
 class IntelMKL(LinAlg):
     """Support for Intel MKL."""
 
+    # library settings are inspired by http://software.intel.com/en-us/articles/intel-mkl-link-line-advisor
     BLAS_MODULE_NAME = ['imkl']
-    BLAS_LIB_MAP = {"lp64":'_lp64',
-                    "interface":None,
-                    "interface_mt":None,
-                    }
+    BLAS_LIB_MAP = {
+        "lp64": '_lp64',
+        "interface": None,
+        "interface_mt": None,
+    }
     BLAS_LIB = ["mkl_%(interface)s%(lp64)s" , "mkl_sequential", "mkl_core"]
     BLAS_LIB_MT = ["mkl_%(interface)s%(lp64)s" , "mkl_%(interface_mt)s_thread", "mkl_core"]
     BLAS_LIB_GROUP = True
@@ -59,8 +61,8 @@ class IntelMKL(LinAlg):
     BLACS_LIB_STATIC = True
 
     SCALAPACK_MODULE_NAME = ['imkl']
-    SCALAPACK_LIB = ["mkl_scalapack%(lp64_sc)s", "mkl_solver%(lp64)s_sequential"]
-    SCALAPACK_LIB_MT = ["mkl_scalapack%(lp64_sc)s", "mkl_solver%(lp64)s"]
+    SCALAPACK_LIB = ["mkl_scalapack%(lp64_sc)s"]
+    SCALAPACK_LIB_MT = ["mkl_scalapack%(lp64_sc)s"]
     SCALAPACK_LIB_MAP = {"lp64_sc":"_lp64"}
     SCALAPACK_REQUIRES = ['LIBBLACS', 'LIBBLAS']
     SCALAPACK_LIB_GROUP = True
@@ -69,21 +71,21 @@ class IntelMKL(LinAlg):
     def _set_blas_variables(self):
         """Fix the map a bit"""
         interfacemap = {
-                        TC_CONSTANT_INTELCOMP: 'intel',
-                        TC_CONSTANT_GCC: 'gf',
-                       }
+            TC_CONSTANT_INTELCOMP: 'intel',
+            TC_CONSTANT_GCC: 'gf',
+        }
         try:
             self.BLAS_LIB_MAP.update({
-                                      "interface":interfacemap[self.COMPILER_FAMILY]
-                                      })
+                "interface": interfacemap[self.COMPILER_FAMILY],
+            })
         except:
             self.log.raiseException(("_set_blas_variables: interface unsupported combination"
-                                    " with MPI family %s") % self.COMPILER_FAMILY)
+                                     " with MPI family %s") % self.COMPILER_FAMILY)
 
         interfacemap_mt = {
-                           TC_CONSTANT_INTELCOMP: 'intel',
-                           TC_CONSTANT_GCC: 'gnu',
-                          }
+            TC_CONSTANT_INTELCOMP: 'intel',
+            TC_CONSTANT_GCC: 'gnu',
+        }
         try:
             self.BLAS_LIB_MAP.update({"interface_mt":interfacemap_mt[self.COMPILER_FAMILY]})
         except:
@@ -92,12 +94,12 @@ class IntelMKL(LinAlg):
 
 
         if self.options.get('32bit', None):
-            ## 32bit
+            # 32bit
             self.BLAS_LIB_MAP.update({"lp64":''})
         if self.options.get('i8', None):
-            ## ilp64/i8
+            # ilp64/i8
             self.BLAS_LIB_MAP.update({"lp64":'_ilp64'})
-            ## CPP / CFLAGS
+            # CPP / CFLAGS
             self.variables.nappend_el('CFLAGS', 'DMKL_ILP64')
 
         # exact paths/linking statements depend on imkl version
@@ -121,13 +123,13 @@ class IntelMKL(LinAlg):
 
     def _set_blacs_variables(self):
         mpimap = {
-                  "OpenMPI": '_openmpi',
-                  "IntelMPI": '_intelmpi',
-                  "MVAPICH2": '_intelmpi',
-                  "MPICH2":'',
-                  }
+            "OpenMPI": '_openmpi',
+            "IntelMPI": '_intelmpi',
+            "MVAPICH2": '_intelmpi',
+            "MPICH2":'',
+        }
         try:
-            self.BLACS_LIB_MAP.update({'mpi':mpimap[self.MPI_FAMILY]})
+            self.BLACS_LIB_MAP.update({'mpi': mpimap[self.MPI_FAMILY]})
         except:
             self.log.raiseException(("_set_blacs_variables: mpi unsupported combination with"
                                      " MPI family %s") % self.MPI_FAMILY)
@@ -138,12 +140,17 @@ class IntelMKL(LinAlg):
         super(IntelMKL, self)._set_blacs_variables()
 
     def _set_scalapack_variables(self):
+        imkl_version = self.get_software_version(self.BLAS_MODULE_NAME)[0]
+        if LooseVersion(imkl_version) < LooseVersion('10.3'):
+            self.SCALAPACK_LIB.append("mkl_solver%(lp64)s_sequential")
+            self.SCALAPACK_LIB_MT.append("mkl_solver%(lp64)s")
+
         if self.options.get('32bit', None):
-            ##32 bit
+            # 32 bit
             self.SCALAPACK_LIB_MAP.update({"lp64_sc":'_core'})
 
         elif self.options.get('i8', None):
-            ## ilp64/i8
+            # ilp64/i8
             self.SCALAPACK_LIB_MAP.update({"lp64_sc":'_ilp64'})
 
         super(IntelMKL, self)._set_scalapack_variables()
