@@ -41,13 +41,14 @@ import re
 import StringIO
 import sys
 import textwrap
-from optparse import OptionParser, OptionGroup, Option, Values, BadOptionError, SUPPRESS_USAGE, OptionValueError
+from optparse import OptionParser, OptionGroup, Option, Values, HelpFormatter
+from optparse import BadOptionError, SUPPRESS_USAGE, NO_DEFAULT, OptionValueError
 from optparse import SUPPRESS_HELP as nohelp  # supported in optparse of python v2.4
 from optparse import _ as _gettext  # this is gettext normally
 from vsc.utils.dateandtime import date_parser, datetime_parser
 from vsc.utils.fancylogger import getLogger, setLogLevel
 from vsc.utils.missing import shell_quote
-
+from vsc.utils.optcomplete import autocomplete, CompleterOption
 
 def set_columns(cols=None):
     """Set os.environ COLUMNS variable
@@ -86,12 +87,13 @@ def check_str_list_tuple(option, opt, value):
         raise OptionValueError(err)
 
 
-class ExtOption(Option):
+class ExtOption(CompleterOption):
     """Extended options class
         - enable/disable support
 
        Actions:
          - shorthelp : hook for shortend help messages
+         - confighelp : hook for configfile-style help messages
          - store_debuglog : turns on fancylogger debugloglevel
             - also: 'store_infolog', 'store_warninglog'
          - extend : extend default list (or create new one if is None)
@@ -111,9 +113,9 @@ class ExtOption(Option):
     EXTOPTION_EXTRA_OPTIONS = ('extend', 'date', 'datetime', 'regex',)
     EXTOPTION_STORE_OR = ('store_or_None',)  # callback type
     EXTOPTION_LOG = ('store_debuglog', 'store_infolog', 'store_warninglog',)
+    EXTOPTION_HELP = ('shorthelp', 'confighelp',)
 
-    # shorthelp has no extra arguments
-    ACTIONS = Option.ACTIONS + EXTOPTION_EXTRA_OPTIONS + EXTOPTION_STORE_OR + EXTOPTION_LOG + ('shorthelp',)
+    ACTIONS = Option.ACTIONS + EXTOPTION_EXTRA_OPTIONS + EXTOPTION_STORE_OR + EXTOPTION_LOG + EXTOPTION_HELP
     STORE_ACTIONS = Option.STORE_ACTIONS + EXTOPTION_EXTRA_OPTIONS + EXTOPTION_LOG + ('store_or_None',)
     TYPED_ACTIONS = Option.TYPED_ACTIONS + EXTOPTION_EXTRA_OPTIONS + EXTOPTION_STORE_OR
     ALWAYS_TYPED_ACTIONS = Option.ALWAYS_TYPED_ACTIONS + EXTOPTION_EXTRA_OPTIONS
@@ -163,6 +165,9 @@ class ExtOption(Option):
         if action == 'shorthelp':
             parser.print_shorthelp()
             parser.exit()
+        elif action == 'confighelp':
+            parser.print_confighelp()
+            parser.exit()
         elif action in ('store_true', 'store_false',) + self.EXTOPTION_LOG:
             if action in self.EXTOPTION_LOG:
                 action = 'store_true'
@@ -270,8 +275,33 @@ class PassThroughOptionParser(OptionParser):
                 break
 
 
+class ExtOptionGroup(OptionGroup):
+    """An OptionGroup with support for configfile section names"""
+    RESERVED_SECTIONS = ['DEFAULT']
+    NO_SECTION = ('NO', 'SECTION')
+
+    def __init__(self, *args, **kwargs):
+        self.log = getLogger(self.__class__.__name__)
+        section_name = kwargs.pop('section_name', None)
+        if section_name in self.RESERVED_SECTIONS:
+            self.log.raiseException('Cannot use reserved name %s for section name.' % section_name)
+
+        OptionGroup.__init__(self, *args, **kwargs)
+        self.section_name = section_name
+        self.section_options = []
+
+    def add_option(self, *args, **kwargs):
+        """Extract configfile section info"""
+        option = OptionGroup.add_option(self, *args, **kwargs)
+        self.section_options.append(option)
+
+        return option
+
+
 class ExtOptionParser(OptionParser):
-    """Make an option parser that limits the C{-h} / C{--shorthelp} to short opts only, C{-H} / C{--help} for all options
+    """
+    Make an option parser that limits the C{-h} / C{--shorthelp} to short opts only,     
+    C{-H} / C{--help} for all options.
 
     Pass options through environment. Like:
 
@@ -438,6 +468,45 @@ class ExtOptionParser(OptionParser):
 
         OptionParser.print_help(self, fh)
 
+    def print_confighelp(self, fh=None):
+        """Print help as a configfile."""
+
+        # walk through all optiongroups
+        # append where necessary, keep track of sections
+        all_groups = {}
+        sections = []
+        for gr in self.option_groups:
+            section = gr.section_name
+            if not (section is None or section == ExtOptionGroup.NO_SECTION):
+                if not section in sections:
+                    sections.append(section)
+                ag = all_groups.setdefault(section, [])
+                ag.extend(gr.section_options)
+
+        # set MAIN section first if exists
+        main_idx = sections.index('MAIN')
+        if main_idx > 0:  # not needed if it main_idx == 0
+            sections.remove('MAIN')
+            sections.insert(0, 'MAIN')
+
+        option_template = "# %(help)s\n#%(option)s=\n"
+        txt = ''
+        for section in sections:
+            txt += "[%s]\n" % section
+            for option in all_groups[section]:
+                data = {
+                    'help': option.help,
+                    'option': option.get_opt_string().lstrip('-'),
+                }
+                txt += option_template % data
+            txt += "\n"
+
+        # overwrite the format_help to be able to use the the regular print_help
+        def format_help(*args, **kwargs):
+            return txt
+        self.format_help = format_help
+        self.print_help(fh)
+
     def _add_help_option(self):
         """Add shorthelp and longhelp"""
         self.add_option("-%s" % self.shorthelp[0],
@@ -448,6 +517,9 @@ class ExtOptionParser(OptionParser):
                         self.longhelp[1],  # *self.longhelp[1:], syntax error in Python 2.4
                         action="help",
                         help=_gettext("show full help message and exit"))
+        self.add_option("--confighelp",
+                        action="confighelp",
+                        help=_gettext("show help as annotated configfile"))
 
     def _get_args(self, args):
         """Prepend the options set through the environment"""
@@ -520,7 +592,9 @@ class GeneralOption(object):
             if True, an option --configfiles will be added
         - go_configfiles : list of configfiles to parse. Uses ConfigParser.read; last file wins
         - go_loggername : name of logger, default classname
-        - go_initbeforedefault : set the main options before the default ones
+        - go_mainbeforedefault : set the main options before the default ones
+        - go_autocompleter : dict with named options to pass to the autocomplete call (eg arg_completer)
+            if is None: disable autocompletion; default is {} (ie no extra args passed)
 
     Sections starting with the string 'raw_' in the sectionname will be parsed as raw sections,
     meaning there will be no interpolation of the strings. This comes in handy if you want to configure strings
@@ -570,6 +644,7 @@ class GeneralOption(object):
         self.configfiles = kwargs.pop('go_configfiles', self.CONFIGFILES_INIT)  # configfiles to parse
         prefixloggername = kwargs.pop('go_prefixloggername', False)  # name of logger is same as envvar prefix
         mainbeforedefault = kwargs.pop('go_mainbeforedefault', False)  # Set the main options before the default ones
+        autocompleter = kwargs.pop('go_autocompleter', {})  # Pass these options to the autocomplete call
 
         set_columns(kwargs.pop('go_columns', None))
 
@@ -594,6 +669,8 @@ class GeneralOption(object):
         self.options = None
         self.args = None
 
+        self.autocompleter = autocompleter
+
         self.auto_prefix = None
         self.auto_section_name = None
 
@@ -662,7 +739,7 @@ class GeneralOption(object):
         }
         descr = ['Configfile options', '']
         self.log.debug("Add configfiles options descr %s opts %s (no prefix)" % (descr, opts))
-        self.add_group_parser(opts, descr, prefix=None)
+        self.add_group_parser(opts, descr, prefix=None, section_name=ExtOptionGroup.NO_SECTION)
 
     def main_options(self):
         """Create the main options automatically"""
@@ -747,19 +824,25 @@ class GeneralOption(object):
         self.log.debug("add_group_parser: set prefix %s section_name %s" % (prefix, section_name))
 
         # add the section name to the help output
-        section_help = "(configfile section %s)" % (section_name)
+        if section_name is None or section_name == ExtOptionGroup.NO_SECTION:
+            section_help = ''
+        else:
+            section_help = " (configfile section %s)" % (section_name)
+
         if description[1]:
             short_description = description[0]
-            long_description = "%s %s" % (description[1], section_help)
+            long_description = "%s%s" % (description[1], section_help)
         else:
-            short_description = "%s %s" % (description[0], section_help)
+            short_description = "%s%s" % (description[0], section_help)
             long_description = description[1]
 
-        opt_grp = OptionGroup(self.parser, short_description, long_description)
+        opt_grp = ExtOptionGroup(self.parser, short_description, long_description, section_name=section_name)
         keys = opt_dict.keys()
         if self.OPTIONGROUP_SORTED_OPTIONS:
             keys.sort()  # alphabetical
         for key in keys:
+            completer = None
+
             details = opt_dict[key]
 
             hlp = details[0]
@@ -817,9 +900,13 @@ class GeneralOption(object):
                         # choices
                         nameds['choices'] = ["%s" % x for x in extra_detail]  # force to strings
                         hlp += ' (choices: %s)' % ', '.join(nameds['choices'])
-                    elif isinstance(extra_detail, (str,)) and len(extra_detail) == 1:
+                    elif isinstance(extra_detail, basestring) and len(extra_detail) == 1:
                         args.insert(0, "-%s" % extra_detail)
                     elif isinstance(extra_detail, (dict,)):
+                        # extract any optcomplete completer hints
+                        completer = extra_detail.pop('completer', None)
+
+                        # add remainder
                         passed_kwargs.update(extra_detail)
                     else:
                         self.log.raiseException("add_group_parser: unknown extra detail %s" % extra_detail)
@@ -833,7 +920,10 @@ class GeneralOption(object):
 
             # force passed_kwargs as final nameds
             nameds.update(passed_kwargs)
-            opt_grp.add_option(*args, **nameds)
+            opt = opt_grp.add_option(*args, **nameds)
+
+            if completer is not None:
+                opt.completer = completer
 
         self.parser.add_option_group(opt_grp)
 
@@ -847,11 +937,22 @@ class GeneralOption(object):
         """Return default options"""
         return sys.argv[1:]
 
+    def autocomplete(self):
+        """Set the autocompletion magic via optcomplete"""
+        # very basic for now, no special options
+        if self.autocompleter is None:
+            self.log.debug('self.autocompleter is None, disabling autocompleter')
+        else:
+            self.log.debug('setting autocomplete with args %s' % self.autocompleter)
+            autocomplete(self.parser, **self.autocompleter)
+
     def parseoptions(self, options_list=None):
         """Parse the options"""
         if options_list is None:
             options_list = self.default_parseoptions()
 
+        self.autocomplete()
+
         try:
             (self.options, self.args) = self.parser.parse_args(options_list)
         except SystemExit, err:
@@ -951,8 +1052,11 @@ class GeneralOption(object):
         for prefix, section_names in self.config_prefix_sectionnames_map.items():
             for section in section_names:
                 # default section is treated separate in ConfigParser
-                if not (self.configfile_parser.has_section(section) or section.lower() == 'default'):
-                    self.log.debug('parseconfigfiles: no section %s' % section)
+                if not self.configfile_parser.has_section(section) or section == ExtOptionGroup.NO_SECTION:
+                    self.log.debug('parseconfigfiles: no section %s' % str(section))
+                    continue
+                elif section.lower() == 'default':
+                    self.log.debug('parseconfigfiles: ignoring default section %s' % section)
                     continue
 
                 for opt, val in self.configfile_parser.items(section):
@@ -966,7 +1070,7 @@ class GeneralOption(object):
 
                     configfile_options_default[opt_dest] = actual_option.default
 
-                    if actual_option.action in ('store_true', 'store_false',):
+                    if actual_option.action in ('store_true', 'store_false',) + ExtOption.EXTOPTION_LOG:
                         try:
                             newval = self.configfile_parser.getboolean(section, opt)
                             self.log.debug(('parseconfigfiles: getboolean for option %s value %s '
@@ -974,7 +1078,17 @@ class GeneralOption(object):
                         except:
                             self.log.raiseException(('parseconfigfiles: failed to getboolean for option %s value %s '
                                                      'in section %s') % (opt, val, section))
-                        configfile_values[opt_dest] = newval
+                        if hasattr(self.parser.option_class, 'ENABLE') and hasattr(self.parser.option_class, 'DISABLE'):
+                            if newval:
+                                cmd_template = "--enable-%s"
+                            else:
+                                cmd_template = "--disable-%s"
+                            configfile_cmdline_dest.append(opt_dest)
+                            configfile_cmdline.append(cmd_template % opt_name)
+                        else:
+                            self.log.debug(("parseconfigfiles: no enable/disable, not trying to set boolean-valued "
+                                            "option %s via cmdline, just setting value to %s" % (opt_name, newval)))
+                            configfile_values[opt_dest] = newval
                     else:
                         configfile_cmdline_dest.append(opt_dest)
                         configfile_cmdline.append("--%s" % opt_name)
@@ -1130,11 +1244,11 @@ class GeneralOption(object):
                     self.log.debug("generate_cmd_line %s adding %s non-default value %s" %
                                    (action, opt_name, opt_value))
                     args.append("--%s=%s" % (opt_name, shell_quote(opt_value)))
-            elif action in ("store_true", "store_false", 'store_debuglog'):
+            elif action in ("store_true", "store_false",) + ExtOption.EXTOPTION_LOG:
                 # not default!
                 self.log.debug("generate_cmd_line adding %s value %s. store action found" %
                                (opt_name, opt_value))
-                if (action in ('store_true', 'store_debuglog',) and default is True and opt_value is False) or \
+                if (action in ('store_true',) + ExtOption.EXTOPTION_LOG and default is True and opt_value is False) or \
                     (action in ('store_false',) and default is False and opt_value is True):
                     if hasattr(self.parser.option_class, 'ENABLE') and hasattr(self.parser.option_class, 'DISABLE'):
                         args.append("--%s-%s" % (self.parser.option_class.DISABLE, opt_name))
@@ -1143,7 +1257,7 @@ class GeneralOption(object):
                                         "with missing ENABLE/DISABLE in option_class") %
                                        (opt_name, default, action))
                 else:
-                    if opt_value == default and ((action in ('store_true', 'store_debuglog',) and default is False)
+                    if opt_value == default and ((action in ('store_true',) + ExtOption.EXTOPTION_LOG and default is False)
                                                  or (action in ('store_false',) and default is True)):
                         if hasattr(self.parser.option_class, 'ENABLE') and \
                             hasattr(self.parser.option_class, 'DISABLE'):
